package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.flys.artifacts.model.FacetTypes;

import de.intevation.artifactdatabase.state.Facet;
import de.intevation.artifactdatabase.state.DefaultOutput;

import de.intevation.flys.artifacts.FLYSArtifact;

import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

/**
 * Yet, a non-abstract DefaultState.
 */
public class StaticState
extends      DefaultState
implements   FacetTypes
{
    /** The logger that is used in this state. */
    private static final Logger logger = Logger.getLogger(StaticState.class);


    /**
     * Trivial constructor, sets id and description.
     * @param id String used for both id and description.
     */
    public StaticState(String id) {
        this(id, id);
    }


    public StaticState(String id, String description) {
        super();
        setID(id);
        setDescription(description);
    }

    public void addDefaultChartOutput(String nameDesc, List<Facet> facets) {
        DefaultOutput output = new DefaultOutput(nameDesc,
            nameDesc, "image/png", facets, "chart");
        getOutputs().add(output);
    }


    /**
     * Do nothing (override to include your logic).
     * @param facets List of facets (to add to).
     */
    public Object staticCompute(List<Facet> facets) {
        return null;
    }


    /** Call staticCompute to allow easy adjustments. */
    @Override
    public Object computeAdvance(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets,
        Object       old
    ) {
        return staticCompute(facets);
    }


    /** Call staticCompute to allow easy adjustments. */
    @Override
    public Object computeFeed(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets,
        Object       old
    ) {
        return staticCompute(facets);
    }


    /** Call staticCompute to allow easy adjustments. */
    @Override
    public Object computeInit(
        FLYSArtifact artifact,
        String       hash,
        Object       context,
        CallMeta     meta,
        List<Facet>  facets
    ) {
        return staticCompute(facets);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
